@@ -43,6 +43,8 @@ class Viset(object):
         
     def __getattr__(self, viewname):
         """Return static and dynamic attributes"""
+        if viewname == 'cache':
+            return self._cache
         for node in self._obj.root:
             if node._v_attrs.viewname == viewname:
                 viewmodule = sys.modules['viset.views']
