@@ -23,7 +23,7 @@ def kfold(n, folds, step=1, randomize=False, stratify=False):
     split = []
     for f in range(0,folds):
         u = f*foldsize 
-        v = u + foldsize - 1       
+        v = u + foldsize    
         k_test = list(k[u:v])
         k_train = list(k)  # copy required
         k_train[u:v] = []
