@@ -88,8 +88,12 @@ class LeafView(View):
         """Return dynamically constructed attributes"""
         if self._state == 'leaf' and name in ['kfold','fold']:            
             self._state = 'kfold'
-        elif name in ['kfold', 'train', 'test', 'validate']:
+        elif self._state == 'leaf' and name in ['train', 'test', 'validate']:
             self._state = name
+        elif self._state == 'kfold' and name in ['train', 'test', 'validate']:
+            self._state = name            
+        elif self._state in ['train', 'test', 'validate'] and name in ['train', 'test', 'validate']:
+            self._state = name  # allows infinite .test.train for kfold iterators
         else:  raise AttributeError, name
         return self
 
